/**
 * @param {API.AccessConfirm} capability
 */
export function parse(capability: API.AccessConfirm): {
    account: API.UCAN.Signer<`did:mailto:${string}` & `did:${string}` & API.Phantom<{
        protocol: "did:";
    }>, 53248>;
    agent: API.Verifier<`did:${string}:${string}`, API.SigAlg>;
};
/**
 * @param {API.Input<Access.confirm>} input
 * @param {API.AccessServiceContext} ctx
 * @returns {Promise<API.Result<API.AccessConfirmSuccess, API.AccessConfirmFailure>>}
 */
export function confirm({ capability, invocation }: API.Input<API.TheCapabilityParser<API.CapabilityMatch<"access/confirm", `did:${string}:${string}` & `did:${string}` & API.Phantom<{
    protocol: "did:";
}>, Provider.Schema.InferStruct<{
    cause: Provider.Schema.Schema<API.Link<unknown, number, number, 1>, any>;
    iss: Provider.Schema.Schema<`did:mailto:${string}` & `did:${string}` & API.Phantom<{
        protocol: "did:";
    }>, any>;
    aud: Provider.Schema.Schema<`did:${string}:${string}` & `did:${string}` & API.Phantom<{
        protocol: "did:";
    }>, any>;
    att: Provider.Schema.Schema<Provider.Schema.InferStruct<{
        can: Provider.Schema.StringSchema<string, unknown>;
    }>[], unknown>;
}>>>>, ctx: API.AccessServiceContext): Promise<API.Result<API.AccessConfirmSuccess, API.AccessConfirmFailure>>;
/**
 * @param {object} opts
 * @param {API.Signer} opts.service
 * @param {API.Principal<API.DID<'mailto'>>} opts.account
 * @param {API.Principal<API.DID>} opts.agent
 * @param {API.Fact[]} opts.facts
 * @param {API.Capabilities} opts.capabilities
 * @param {API.Delegation[]} opts.delegationProofs
 * @param {number} opts.expiration
 * @returns {Promise<[delegation: API.Delegation, attestation: API.Delegation]>}
 */
export function createSessionProofs({ service, account, agent, facts, capabilities, delegationProofs, expiration, }: {
    service: API.Signer;
    account: API.Principal<API.DID<'mailto'>>;
    agent: API.Principal<API.DID>;
    facts: API.Fact[];
    capabilities: API.Capabilities;
    delegationProofs: API.Delegation[];
    expiration: number;
}): Promise<[delegation: API.Delegation<API.Capabilities>, attestation: API.Delegation<API.Capabilities>]>;
export function provide(ctx: API.AccessServiceContext): API.ServiceMethod<API.Capability<"access/confirm", `did:${string}:${string}` & `did:${string}` & API.Phantom<{
    protocol: "did:";
}>, Pick<{
    cause: API.Link<unknown, number, number, 1>;
    iss: `did:mailto:${string}` & `did:${string}` & API.Phantom<{
        protocol: "did:";
    }>;
    aud: `did:${string}:${string}` & `did:${string}` & API.Phantom<{
        protocol: "did:";
    }>;
    att: Provider.Schema.InferStruct<{
        can: Provider.Schema.StringSchema<string, unknown>;
    }>[];
}, "att" | "iss" | "aud" | "cause">>, API.AccessConfirmSuccess, API.Failure & API.AccessConfirmFailure>;
import * as API from '../types.js';
import * as Provider from '@ucanto/server';
//# sourceMappingURL=confirm.d.ts.map