/**
 * @param {API.BlobServiceContext} context
 */
export function createService(context: API.BlobServiceContext): {
    add: API.ServiceMethod<{
        can: "space/blob/add";
        with: `did:key:${string}` & `did:${string}` & API.Phantom<{
            protocol: "did:";
        }> & `${string}:${string}`;
        nb: Pick<{
            blob: import("@ucanto/validator").InferStruct<{
                digest: import("@ucanto/core/schema").Schema<Uint8Array, unknown>;
                size: import("@ucanto/validator").NumberSchema<number & API.Phantom<{
                    typeof: "integer";
                }>, unknown>;
            }>;
        }, "blob"> & Partial<Pick<{
            blob: import("@ucanto/validator").InferStruct<{
                digest: import("@ucanto/core/schema").Schema<Uint8Array, unknown>;
                size: import("@ucanto/validator").NumberSchema<number & API.Phantom<{
                    typeof: "integer";
                }>, unknown>;
            }>;
        }, never>>;
    }, API.BlobAddSuccess, API.BlobAddFailure>;
    list: API.ServiceMethod<{
        can: "space/blob/list";
        with: `did:key:${string}` & `did:${string}` & API.Phantom<{
            protocol: "did:";
        }> & `${string}:${string}`;
        nb: Pick<{
            cursor: string | undefined;
            size: (number & API.Phantom<{
                typeof: "integer";
            }>) | undefined;
        }, never> & Partial<Pick<{
            cursor: string | undefined;
            size: (number & API.Phantom<{
                typeof: "integer";
            }>) | undefined;
        }, "size" | "cursor">>;
    }, API.BlobListSuccess, API.Failure>;
    remove: API.ServiceMethod<{
        can: "space/blob/remove";
        with: `did:key:${string}` & `did:${string}` & API.Phantom<{
            protocol: "did:";
        }> & `${string}:${string}`;
        nb: Pick<{
            digest: Uint8Array;
        }, "digest"> & Partial<Pick<{
            digest: Uint8Array;
        }, never>>;
    }, API.BlobRemoveSuccess, API.Failure>;
    get: {
        0: {
            1: API.ServiceMethod<{
                can: "space/blob/get/0/1";
                with: `did:key:${string}` & `did:${string}` & API.Phantom<{
                    protocol: "did:";
                }> & `${string}:${string}`;
                nb: Pick<{
                    digest: Uint8Array;
                }, "digest"> & Partial<Pick<{
                    digest: Uint8Array;
                }, never>>;
            }, API.BlobGetSuccess, API.Failure>;
        };
    };
};
export { BlobNotFound } from "./blob/lib.js";
import * as API from './types.js';
//# sourceMappingURL=blob.d.ts.map