export const AllocatedMemoryHadNotBeenWrittenToName: "AllocatedMemoryHadNotBeenWrittenTo";
export class AllocatedMemoryHadNotBeenWrittenTo extends Failure {
    get name(): string;
}
export const BlobSizeOutsideOfSupportedRangeName: "BlobSizeOutsideOfSupportedRange";
export class BlobSizeOutsideOfSupportedRange extends Failure {
    /**
     * @param {number} blobSize
     * @param {number} maxUploadSize
     */
    constructor(blobSize: number, maxUploadSize: number);
    blobSize: number;
    maxUploadSize: number;
    get name(): string;
    toJSON(): {
        maxUploadSize: number;
        blobSize: number;
        name: string;
        message: string;
        stack: string | undefined;
    };
}
export const AwaitErrorName: "AwaitError";
/**
 * @implements {API.AwaitError}
 */
export class AwaitError extends Failure implements API.AwaitError {
    /**
     * @param {object} source
     * @param {string} source.at - argument path that referenced failed `await`
     * @param {import('@ucanto/interface').UnknownLink} source.reference - awaited reference that failed
     * @param {import('@ucanto/interface').Failure} source.cause - error that caused referenced `await` to fail
     */
    constructor({ at, reference, cause }: {
        at: string;
        reference: import('@ucanto/interface').UnknownLink;
        cause: import('@ucanto/interface').Failure;
    });
    at: string;
    reference: API.UnknownLink;
    cause: API.Failure;
    /**
     * @type {'AwaitError'}
     */
    get name(): "AwaitError";
}
export class BlobNotFound extends Failure {
    static name: "BlobNotFound";
    /** @param {import('multiformats').MultihashDigest} digest */
    constructor(digest: import('multiformats').MultihashDigest);
    get name(): "BlobNotFound";
    get digest(): Uint8Array;
    #private;
}
export class UnsupportedCapability extends Failure {
    /**
     * @param {object} source
     * @param {API.Capability} source.capability
     */
    constructor({ capability: { with: subject, can } }: {
        capability: API.Capability;
    });
    capability: {
        with: `${string}:${string}`;
        can: API.Ability;
    };
    get name(): "UnsupportedCapability";
}
import { Failure } from '@ucanto/server';
import * as API from '../types.js';
//# sourceMappingURL=lib.d.ts.map