/**
 * @param {API.BlobServiceContext} context
 */
export function createService(context: API.BlobServiceContext): {
    blob: {
        allocate: API.ServiceMethod<{
            can: "web3.storage/blob/allocate";
            with: `did:${string}:${string}` & `did:${string}` & API.Phantom<{
                protocol: "did:";
            }> & `${string}:${string}`;
            nb: Pick<{
                blob: import("@ucanto/validator").InferStruct<{
                    digest: import("@ucanto/core/schema").Schema<Uint8Array, unknown>;
                    size: import("@ucanto/validator").NumberSchema<number & API.Phantom<{
                        typeof: "integer";
                    }>, unknown>;
                }>;
                cause: API.Link<unknown, number, number, 0 | 1>;
                space: `did:key:${string}` & `did:${string}` & API.Phantom<{
                    protocol: "did:";
                }>;
            }, "space" | "cause" | "blob"> & Partial<Pick<{
                blob: import("@ucanto/validator").InferStruct<{
                    digest: import("@ucanto/core/schema").Schema<Uint8Array, unknown>;
                    size: import("@ucanto/validator").NumberSchema<number & API.Phantom<{
                        typeof: "integer";
                    }>, unknown>;
                }>;
                cause: API.Link<unknown, number, number, 0 | 1>;
                space: `did:key:${string}` & `did:${string}` & API.Phantom<{
                    protocol: "did:";
                }>;
            }, never>>;
        }, API.BlobAllocateSuccess, API.BlobAllocateFailure>;
        accept: API.ServiceMethod<{
            can: "web3.storage/blob/accept";
            with: `did:${string}:${string}` & `did:${string}` & API.Phantom<{
                protocol: "did:";
            }> & `${string}:${string}`;
            nb: Pick<{
                blob: import("@ucanto/validator").InferStruct<{
                    digest: import("@ucanto/core/schema").Schema<Uint8Array, unknown>;
                    size: import("@ucanto/validator").NumberSchema<number & API.Phantom<{
                        typeof: "integer";
                    }>, unknown>;
                }>;
                ttl: (number & API.Phantom<{
                    typeof: "integer";
                }>) | undefined;
                space: `did:key:${string}` & `did:${string}` & API.Phantom<{
                    protocol: "did:";
                }>;
                _put: import("@ucanto/validator").InferStruct<{
                    'ucan/await': import("@ucanto/core/schema").Schema<[string, API.Link<unknown, number, number, 0 | 1>], any>;
                }>;
            }, "space" | "blob" | "_put"> & Partial<Pick<{
                blob: import("@ucanto/validator").InferStruct<{
                    digest: import("@ucanto/core/schema").Schema<Uint8Array, unknown>;
                    size: import("@ucanto/validator").NumberSchema<number & API.Phantom<{
                        typeof: "integer";
                    }>, unknown>;
                }>;
                ttl: (number & API.Phantom<{
                    typeof: "integer";
                }>) | undefined;
                space: `did:key:${string}` & `did:${string}` & API.Phantom<{
                    protocol: "did:";
                }>;
                _put: import("@ucanto/validator").InferStruct<{
                    'ucan/await': import("@ucanto/core/schema").Schema<[string, API.Link<unknown, number, number, 0 | 1>], any>;
                }>;
            }, "ttl">>;
        }, API.BlobAcceptSuccess, API.BlobAcceptFailure>;
    };
};
import * as API from './types.js';
//# sourceMappingURL=service.d.ts.map