/**
 * Return whether the provided stack trace string appears to be generated
 * by a deployed upload-api.
 * Heuristics:
 * - stack trace files paths will start with `file:///var/task/upload-api` because of how the lambda environment is working
 *
 * @param {string} stack
 */
export function isUploadApiStack(stack: string): boolean;
/**
 * @param {Types.Signer} issuer
 * @param {Types.Signer<Types.ServiceDID>} service
 * @param {Types.ConnectionView<import('@web3-storage/access/types').Service>} conn
 * @param {`${string}@${string}`} email
 */
export function createSpace(issuer: Types.Signer, service: Types.Signer<Types.ServiceDID>, conn: Types.ConnectionView<import('@web3-storage/access/types').Service>, email: `${string}@${string}`): Promise<{
    space: ed25519.EdSigner;
    delegation: Types.Delegation<[{
        can: "*";
        with: Types.URI<`${string}:`>;
        nb: Partial<any>;
    }]>;
}>;
/**
 * @param {URL} confirmationUrl
 * @returns {Promise<API.Invocation<API.AccessConfirm>>}
 */
export function extractConfirmInvocation(confirmationUrl: URL): Promise<API.Invocation<API.AccessConfirm>>;
/**
 * @param {API.ConnectionView<import('@web3-storage/access').Service>} connection
 * @param {{ url: string|URL }} confirmation
 */
export function confirmConfirmationUrl(connection: API.ConnectionView<import('@web3-storage/access').Service>, confirmation: {
    url: string | URL;
}): Promise<void>;
export { Context };
/** did:key:z6Mkk89bC3JrVqKie71YEcc5M1SMVxuCgNx6zLZ8SYJsxALi */
export const alice: ed25519.EdSigner;
/** did:key:z6MkffDZCkCTWreg8868fG1FGFogcJj5X6PY93pPcWDn9bob */
export const bob: ed25519.EdSigner;
/** did:key:z6MktafZTREjJkvV5mfJxcLpNBoVPwDLhTuMg9ng7dY4zMAL */
export const mallory: ed25519.EdSigner;
/** did:key:z6MkrZ1r5XBFZjBU34qyD8fueMbMRkKw17BZaq2ivKFjnz2z */
export const w3Signer: ed25519.EdSigner;
export const w3: Types.Signer<"did:web:test.web3.storage", ed25519.SigAlg>;
/** did:key:z6MkuKJgV8DKxiAF5oaUcT8ckg8kZUoBe6yavSLnHn5ZgyAP */
export const gatewaySigner: ed25519.EdSigner;
export const gateway: Types.Signer<"did:web:w3s.link", ed25519.SigAlg>;
export function createServer<Service extends Record<string, any>>({ id, service, codec }: {
    service: Service;
    id?: Types.Signer<`did:web:${string}`, Types.SigAlg> | undefined;
    codec?: Types.InboundCodec | undefined;
}): Types.ServerView<Service>;
export function connect<Service extends Record<string, any>>({ id, channel, codec }: {
    id: Types.Principal;
    channel: Types.Channel<Service>;
    codec?: Types.OutboundCodec | undefined;
}): Types.ConnectionView<Service>;
export function createChannel<Service extends Record<string, any>>({ id, service, ...etc }: {
    service: Service;
    id: Server.API.Signer<Server.API.DID<'web'>>;
    server: Types.Channel<Service>;
}): {
    server: Types.ServerView<Service>;
    client: Types.ConnectionView<Service>;
};
export function createAuthorization({ account, agent, service }: {
    account: Types.UCAN.Signer<Types.AccountDID>;
    service: Types.Signer<Types.ServiceDID>;
    agent: Types.Signer;
}): Promise<(Types.Delegation<[{
    with: "ucan:*";
    can: "*";
}]> | Types.Invocation<{
    can: "ucan/attest";
    with: `did:${string}:${string}` & `did:${string}` & Types.Phantom<{
        protocol: "did:";
    }>;
    nb: Server.Schema.InferStruct<{
        proof: Server.Schema.Schema<Types.Link<unknown, number, number, 1>, any>;
    }>;
}>)[]>;
export function provisionProvider({ service, agent, space, account, connection, }: {
    service: Types.Signer<Types.ServiceDID>;
    space: Types.Principal<Types.SpaceDID>;
    agent: Types.Signer<Types.DIDKey>;
    account: Types.UCAN.Signer<Types.AccountDID>;
    connection: Types.ConnectionView<Types.Service>;
}): Promise<Types.Receipt<Types.ProviderAddSuccess, Types.HandlerNotFound | Types.HandlerExecutionError | Types.InvalidAudience | Types.Unauthorized | Types.ProviderAddFailure, Types.Invocation<Types.Capability<Types.Ability, `${string}:${string}`, unknown>>, Types.SigAlg>>;
export function queue<T>(buffer?: T[]): {
    put: (message: T) => void;
    take: () => Promise<T>;
};
export function validateAuthorization(): {
    ok: {};
};
import * as Types from '../../src/types.js';
import { ed25519 } from '@ucanto/principal';
import * as API from '../types.js';
import * as Context from './context.js';
import * as Server from '@ucanto/server';
import { UCAN } from '@web3-storage/capabilities';
//# sourceMappingURL=utils.d.ts.map