export function memory(): AgentStore;
export type Model = {
    store: Record<string, CAR.Model>;
    index: Record<string, {
        root: API.Link;
        at: string;
    }[]>;
};
/**
 * @typedef {object} Model
 * @property {Record<string, CAR.Model>} store
 * @property {Record<string, {root: API.Link, at: string }[]>} index
 *
 * @implements {API.AgentStore}
 */
declare class AgentStore implements API.AgentStore {
    /**
     * @param {Partial<Model>} [model]
     */
    constructor({ store, index, }?: Partial<Model> | undefined);
    model: {
        store: Record<string, CAR.Model>;
        index: Record<string, {
            root: API.Link;
            at: string;
        }[]>;
    };
    invocations: InvocationLookup;
    receipts: ReceiptLookup;
    get messages(): this;
    /**
     * @param {API.ParsedAgentMessage} message
     * @returns {Promise<API.Result<API.Unit, API.WriteError<API.ParsedAgentMessage>>>}
     */
    write(message: API.ParsedAgentMessage): Promise<API.Result<API.Unit, API.WriteError<API.ParsedAgentMessage>>>;
}
import * as API from '../../src/types.js';
declare class InvocationLookup {
    /**
     * @param {Model} model
     */
    constructor(model: Model);
    model: Model;
    /**
     *
     * @param {API.UnknownLink} key
     * @returns {Promise<API.Result<API.Invocation, API.RecordNotFound>>}
     */
    get(key: API.UnknownLink): Promise<API.Result<API.Invocation, API.RecordNotFound>>;
}
declare class ReceiptLookup {
    /**
     * @param {Model} model
     */
    constructor(model: Model);
    model: Model;
    /**
     *
     * @param {API.UnknownLink} key
     * @returns {Promise<API.Result<API.Receipt, API.RecordNotFound>>}
     */
    get(key: API.UnknownLink): Promise<API.Result<API.Receipt, API.RecordNotFound>>;
}
import { Invocation } from '@ucanto/core';
import { RecordNotFound } from '../../src/errors.js';
import { Receipt } from '@ucanto/core';
export {};
//# sourceMappingURL=agent-store.d.ts.map