/// <reference types="node" resolution-mode="require"/>
/**
 * @implements {Types.BlobsStorage}
 * @implements {Types.BlobRetriever}
 */
export class BlobsStorage implements Types.BlobsStorage, Types.BlobRetriever {
    /**
     * @param {Types.CarStoreBucketOptions & {http?: import('http')}} options
     */
    static activate({ http, ...options }?: Types.CarStoreBucketOptions & {
        http?: typeof import("http");
    }): Promise<BlobsStorage>;
    /**
     * @param {Types.CarStoreBucketOptions & { server?: import('http').Server, url: URL, content: Map<string, Uint8Array> }} options
     */
    constructor({ content, url, server, accessKeyId, secretAccessKey, bucket, region, }: Types.CarStoreBucketOptions & {
        server?: import('http').Server;
        url: URL;
        content: Map<string, Uint8Array>;
    });
    /**
     * @returns {Promise<void>}
     */
    deactivate(): Promise<void>;
    server: import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse> | undefined;
    baseURL: URL;
    accessKeyId: string;
    secretAccessKey: string;
    bucket: string;
    region: string;
    content: Map<string, Uint8Array>;
    /** @param {Types.MultihashDigest} digest */
    has(digest: Types.MultihashDigest): Promise<{
        ok: boolean;
        error?: undefined;
    }>;
    /** @param {Types.MultihashDigest} digest */
    stream(digest: Types.MultihashDigest): Promise<{
        ok?: undefined;
        error: BlobNotFound;
    } | {
        ok: ReadableStream<any>;
        error?: undefined;
    }>;
    /**
     * @param {Types.MultihashDigest} digest
     * @param {number} size
     * @param {number} expiresIn
     */
    createUploadUrl(digest: Types.MultihashDigest, size: number, expiresIn: number): Promise<{
        ok: {
            url: URL;
            headers: {
                'x-amz-checksum-sha256': string;
                'content-length': string;
            };
        };
    }>;
    /** @param {Types.MultihashDigest} digest */
    createDownloadUrl(digest: Types.MultihashDigest): Promise<{
        ok: Types.URI<`${string}:`>;
        error?: undefined;
    }>;
    #private;
}
import * as Types from '../../src/types.js';
import { BlobNotFound } from '../../src/blob/lib.js';
//# sourceMappingURL=blobs-storage.d.ts.map