/// <reference types="node" resolution-mode="require"/>
/**
 * @implements {API.CarStoreBucket}
 */
export class CarStoreBucket implements API.CarStoreBucket {
    /**
     * @param {API.CarStoreBucketOptions & {http?: import('http')}} options
     */
    static activate({ http, ...options }?: API.CarStoreBucketOptions & {
        http?: typeof import("http");
    }): Promise<CarStoreBucket>;
    /**
     * @param {API.CarStoreBucketOptions & { server?: import('http').Server, url: URL, content: Map<string, Uint8Array> }} options
     */
    constructor({ content, url, server, accessKeyId, secretAccessKey, bucket, region, expires, }: API.CarStoreBucketOptions & {
        server?: import('http').Server;
        url: URL;
        content: Map<string, Uint8Array>;
    });
    server: import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse> | undefined;
    baseURL: URL;
    accessKeyId: string;
    secretAccessKey: string;
    bucket: string;
    region: string;
    expires: number | undefined;
    content: Map<string, Uint8Array>;
    /**
     * @returns {Promise<void>}
     */
    deactivate(): Promise<void>;
    /**
     *
     * @param {API.UnknownLink} link
     */
    has(link: API.UnknownLink): Promise<boolean>;
    /**
     * @param {API.UnknownLink} link
     * @param {number} size
     */
    createUploadUrl(link: API.UnknownLink, size: number): Promise<{
        url: URL;
        headers: {
            'x-amz-checksum-sha256': string;
            'content-length': string;
        };
    }>;
}
import * as API from '../../src/types.js';
//# sourceMappingURL=car-store-bucket.d.ts.map