/// <reference types="node" resolution-mode="require"/>
/**
 * @param {object} options
 * @param {string[]} [options.providers]
 * @param {boolean} [options.requirePaymentPlan]
 * @param {import('http')} [options.http]
 * @param {{fail(error:unknown): unknown}} [options.assert]
 */
export function getServiceStorageImplementations(options: {
    providers?: string[] | undefined;
    requirePaymentPlan?: boolean | undefined;
    http?: typeof import("http") | undefined;
    assert?: {
        fail(error: unknown): unknown;
    } | undefined;
}): Promise<{
    storeTable: StoreTable;
    allocationsStorage: AllocationsStorage;
    uploadTable: UploadTable;
    blobsStorage: BlobsStorage;
    blobRetriever: BlobsStorage;
    carStoreBucket: CarStoreBucket;
    revocationsStorage: RevocationsStorage;
    plansStorage: PlansStorage;
    usageStorage: UsageStorage;
    provisionsStorage: ProvisionsStorage;
    subscriptionsStorage: SubscriptionsStorage;
    delegationsStorage: DelegationsStorage;
    rateLimitsStorage: RateLimitsStorage;
    agentStore: {
        model: {
            store: Record<string, import("@ucanto/core/car").Model>;
            index: Record<string, {
                root: import("@ipld/dag-ucan").IPLDLink<any, number, number, 1>;
                at: string;
            }[]>;
        };
        invocations: {
            model: AgentStore.Model;
            get(key: import("@ucanto/interface").UnknownLink): Promise<import("@ucanto/interface").Result<import("@ucanto/interface").Invocation<import("@ipld/dag-ucan").Capability<import("@ipld/dag-ucan").Ability, `${string}:${string}`, unknown>>, import("../types.js").RecordNotFound>>;
        };
        receipts: {
            model: AgentStore.Model;
            get(key: import("@ucanto/interface").UnknownLink): Promise<import("@ucanto/interface").Result<import("@ucanto/interface").Receipt<any, any, import("@ucanto/interface").Invocation<import("@ipld/dag-ucan").Capability<import("@ipld/dag-ucan").Ability, `${string}:${string}`, unknown>>, import("@ipld/dag-ucan").SigAlg>, import("../types.js").RecordNotFound>>;
        };
        readonly messages: any;
        write(message: import("../types.js").ParsedAgentMessage): Promise<import("@ucanto/interface").Result<import("@ucanto/interface").Unit, import("../types.js").WriteError<import("../types.js").ParsedAgentMessage>>>;
    };
}>;
import { StoreTable } from './store-table.js';
import { AllocationsStorage } from './allocations-storage.js';
import { UploadTable } from './upload-table.js';
import { BlobsStorage } from './blobs-storage.js';
import { CarStoreBucket } from './car-store-bucket.js';
import { RevocationsStorage } from './revocations-storage.js';
import { PlansStorage } from './plans-storage.js';
import { UsageStorage } from './usage-storage.js';
import { ProvisionsStorage } from './provisions-storage.js';
import { SubscriptionsStorage } from './subscriptions-storage.js';
import { DelegationsStorage } from './delegations-storage.js';
import { RateLimitsStorage } from './rate-limits-storage.js';
import * as AgentStore from './agent-store.js';
//# sourceMappingURL=index.d.ts.map