/**
 * @implements {Types.PlansStorage}
 */
export class PlansStorage implements Types.PlansStorage {
    /**
     * @type {Record<Types.DID, {product: Types.DID, billingID: string, updatedAt: string}>}
     */
    plans: Record<Types.DID, {
        product: Types.DID;
        billingID: string;
        updatedAt: string;
    }>;
    /**
     *
     * @param {Types.AccountDID} account
     * @param {string} billingID
     * @param {Types.DID} product
     */
    initialize(account: Types.AccountDID, billingID: string, product: Types.DID): Promise<{
        error: CustomerExists;
        ok?: undefined;
    } | {
        ok: {};
        error?: undefined;
    }>;
    /**
     *
     * @param {Types.AccountDID} account
     * @returns
     */
    get(account: Types.AccountDID): Promise<{
        ok: {
            product: Types.DID;
            billingID: string;
            updatedAt: string;
        };
        error?: undefined;
    } | {
        error: {
            name: "PlanNotFound";
            message: string;
        };
        ok?: undefined;
    }>;
    /**
     *
     * @param {Types.AccountDID} account
     * @param {Types.DID} product
     * @returns
     */
    set(account: Types.AccountDID, product: Types.DID): Promise<{
        error: CustomerNotFound;
        ok?: undefined;
    } | {
        ok: {};
        error?: undefined;
    }>;
    /**
     * @param {Types.AccountDID} account
     * @returns {Promise<import('@ucanto/interface').Result<import('../types.js').PlanCreateAdminSessionSuccess, import('../types.js').PlanCreateAdminSessionFailure>>}
     */
    createAdminSession(account: Types.AccountDID): Promise<import('@ucanto/interface').Result<import('../types.js').PlanCreateAdminSessionSuccess, import('../types.js').PlanCreateAdminSessionFailure>>;
}
import * as Types from '../../src/types.js';
//# sourceMappingURL=plans-storage.d.ts.map