/** @typedef {import('../../src/types/usage.js').UsageStorage} UsageStore */
/** @implements {UsageStore} */
export class UsageStorage implements UsageStore {
    /**
     * @param {import('./store-table.js').StoreTable} storeTable
     * @param {import('./allocations-storage.js').AllocationsStorage} allocationsStorage
     */
    constructor(storeTable: import('./store-table.js').StoreTable, allocationsStorage: import('./allocations-storage.js').AllocationsStorage);
    storeTable: import("./store-table.js").StoreTable;
    allocationsStorage: import("./allocations-storage.js").AllocationsStorage;
    /**
     * @type {Record<import('../types.js').AccountDID, import('../types.js').EgressData>}
     */
    _egressRecords: Record<import('../types.js').AccountDID, import('../types.js').EgressData>;
    get items(): ({
        cause: import("../types.js").UCANLink<import("../types.js").Capabilities, import("../types.js").MulticodecCode<number, string>, import("../types.js").SigAlg>;
        space: `did:${string}:${string}`;
        link: import("@web3-storage/capabilities/types").CARLink;
        size: number;
        origin?: import("../types.js").UnknownLink | undefined;
        issuer?: `did:${string}:${string}` | undefined;
        invocation: import("../types.js").UCANLink<import("../types.js").Capabilities, import("../types.js").MulticodecCode<number, string>, import("../types.js").SigAlg>;
        insertedAt: string;
    } | {
        size: number;
        space: `did:${string}:${string}`;
        cause: import("../types.js").UnknownLink;
        blob: import("../../src/types/blob.js").BlobModel & import("@web3-storage/capabilities/types").BlobModel;
        insertedAt: string;
    })[];
    /**
     * @param {import('../types.js').ProviderDID} provider
     * @param {import('../types.js').SpaceDID} space
     * @param {{ from: Date, to: Date }} period
     */
    report(provider: import('../types.js').ProviderDID, space: import('../types.js').SpaceDID, period: {
        from: Date;
        to: Date;
    }): Promise<{
        ok: {
            provider: `did:web:${string}`;
            space: `did:key:${string}`;
            period: {
                from: string;
                to: string;
            };
            size: {
                initial: number;
                final: number;
            };
            events: {
                cause: import("../types.js").Link<any, number, number, 1>;
                delta: number;
                receiptAt: string;
            }[];
        };
    }>;
    /**
     * Simulate a record of egress data for a customer.
     *
     * @param {import('../types.js').SpaceDID} space
     * @param {import('../types.js').AccountDID} customer
     * @param {import('../types.js').UnknownLink} resource
     * @param {number} bytes
     * @param {Date} servedAt
     * @param {import('../types.js').UnknownLink} cause
     */
    record(space: import('../types.js').SpaceDID, customer: import('../types.js').AccountDID, resource: import('../types.js').UnknownLink, bytes: number, servedAt: Date, cause: import('../types.js').UnknownLink): Promise<{
        ok: {
            space: `did:key:${string}`;
            customer: `did:mailto:${string}`;
            resource: import("../types.js").UnknownLink;
            bytes: number;
            servedAt: string;
            cause: import("../types.js").UnknownLink;
        };
    }>;
    get egressRecords(): Record<`did:mailto:${string}`, import("@web3-storage/capabilities/types").EgressData>;
}
export type UsageStore = import('../../src/types/usage.js').UsageStorage;
//# sourceMappingURL=usage-storage.d.ts.map